
%% Initialize
dim=30; %number of states
b = 0.9; % discount factor 
%parameters governing transition of states
theta30 = 0.3;
theta31 = 0.35; 
theta32 = 0.25; 
theta33 = 0.1;

%% Generate true CCP (Conditional Choice Probabilities)
[~,~,p,~,~]=IBE(dim,b,2,0.5,theta30,theta31,theta32,theta33);


%% Generate matrix of transition probabilities
%transition probability when y=1 
Pi1=zeros(dim,dim);
Pi1(:,1)=theta30*ones(dim,1);
Pi1(:,2)=theta31*ones(dim,1);
Pi1(:,3)=theta32*ones(dim,1);
Pi1(:,4)=theta33*ones(dim,1);


%transition probability when y=2 
Pi2=zeros(dim,dim);

Pi2(1:10,1)=theta30*ones(10,1);
Pi2(1:10,2)=theta31*ones(10,1);
Pi2(1:10,3)=theta32*ones(10,1);
Pi2(1:10,4)=theta33*ones(10,1);

for x=11:1:dim
    
    Pi2(x,x-10)=theta30;
    Pi2(x,x-9)=theta31;
    Pi2(x,x-8)=theta32;
    Pi2(x,x-7)=theta33;
    
end

%transition probability for y=3

Pi3=zeros(dim,dim);

for x=1:1:dim-3
    
    Pi3(x,x)=theta30;
    Pi3(x,x+1)=theta31;
    Pi3(x,x+2)=theta32;
    Pi3(x,x+3)=theta33;
    
end

Pi3(dim-2,dim-2)=(theta30)/(theta30+theta31+theta32);
Pi3(dim-2,dim-1)=(theta31)/(theta30+theta31+theta32);
Pi3(dim-2,dim)=(theta32)/(theta30+theta31+theta32);
Pi3(dim-1,dim-1)=(theta30)/(theta30+theta31);
Pi3(dim-1,dim)=(theta31)/(theta30+theta31);
Pi3(dim,dim)=1;


Pi1=Pi1(1:dim,1:dim);
Pi2=Pi2(1:dim,1:dim);
Pi3=Pi3(1:dim,1:dim);

%% Estimate non-parametric per-period utilities given true CCP
%p(x,:) is the vector of observed choice probabilities in state x

L=zeros(dim,3);

for x=1:1:dim
    
    L(x,:)=Gs(p(x,:),5000);
    
end

RC=0;

Vx=(b*Pi3-eye(dim))\(L(:,3)+RC*ones(dim,1));

u=zeros(dim,2);

%% Estimated utilities
u(:,1)=L(:,1)+Vx-b*Pi1*Vx;
u(:,2)=L(:,2)+Vx-b*Pi2*Vx;

% True Utilities
trueu1=-2*ones(30,1)+0.5*sqrt([1:1:30]');
trueu2=-2*ones(30,1)+0.5*0.8*sqrt([1:1:30]');
    
% R-squared
      
rr1=1-(sum((u(:,1)-trueu1).^2)/sum((u(:,1)-mean(u(:,1))).^2))
rr2=1-(sum((u(:,2)-trueu2).^2)/sum((u(:,2)-mean(u(:,2))).^2))
    

%% Generate Figure

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);
box(axes1,'on');
hold(axes1,'on');

% Create xlabel
xlabel('$$x$$, states','FontSize',16,'Interpreter','latex');

% Create multiple lines using matrix input to plot
plot1 = plot([1:1:30],[u(:,1),u(:,2),trueu1,trueu2],'Parent',axes1);
set(plot1(1),'DisplayName','Utility estimates',...
    'MarkerFaceColor',[0.850980401039124 0.325490206480026 0.0980392172932625],...
    'MarkerEdgeColor','none',...
    'Marker','o',...
    'LineStyle','none');
set(plot1(2),'DisplayName','Utility estimates',...
    'MarkerFaceColor',[0 0.447058826684952 0.74117648601532],...
    'MarkerEdgeColor','none',...
    'Marker','o',...
    'LineStyle','none');
set(plot1(3),'DisplayName','$$\bar{u}(y=0,x) = -2 + 0.5\sqrt{x}$$',...
    'LineWidth',1.5,...
    'Color',[0.850980401039124 0.325490206480026 0.0980392172932625]);
set(plot1(4),'DisplayName','$$\bar{u}(y=1,x) = -2 + 0.4\sqrt{x}$$',...
    'LineWidth',1.5,...
    'Color',[0 0.447058826684952 0.74117648601532]);

% Create legend
legend1 = legend(axes1,'show');
set(legend1,...
    'Position',[0.552459016393443 0.147138964577657 0.318032786885246 0.204359673024523],...
    'Interpreter','latex',...
    'FontSize',12);

