function gap=sizeset(S,p)

% S is the number of discretized points of the unobserved dist. 
% p is the 3-by-1 vector of choice probabilities
% gap(i) gives the size of the identified set of payoffs for choice y=i 


D=numel(p); %D is the number of choices. Here, D=3
%e is a S-by-D vector of S number of draws from the D-dimemsional 
%distribution of unobserved heterogeneity.
e=mvnrnd([0,0],[0.5,0.5;0.5,1],S); %2d gaussian


%Aeq is a S+D by D*S matrix of equality constraints:
Aeq=zeros(S+D,D*S);
for d=1:1:D
    Aeq(d,(d-1)*S+1:d*S)=ones(1,S);
    Aeq(D+1:D+S,(d-1)*S+1:d*S)=eye(S);
end

%The linear objective vector
f=zeros(D*S,1);
for d=1:1:D-1
    f((d-1)*S+1:d*S)=e(:,d);
end

f((D-1)*S+1:D*S)=zeros(S,1);
f=-f;

%The right-hand side vector for the linear constraints
w=(1/S)*ones(S,1);
rhs=[p;w];

%lower bound vector
lb=zeros(D*S,1);

%options = optimset('LargeScale', 'off', 'Simplex', 'on','MaxIter',10000);

options=optimset('Display', 'off');

[~,fval,~,~,~]=linprog(f,[],[],Aeq,rhs,lb,[],[],options);

Ceq=[p',zeros(1,S);zeros(1,D),w'];

I=eye(D);

[low1,~,exitflag]=linprog([I(:,1);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

[low2,~,exitflag]=linprog([I(:,2);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

[low3,~,exitflag]=linprog([I(:,3);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

[up1,~,exitflag]=linprog(-[I(:,1);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

[up2,~,exitflag]=linprog(-[I(:,2);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

[up3,~,exitflag]=linprog(-[I(:,3);zeros(S,1)],Aeq',f,Ceq,[fval;0],[],[],[],options);

low=[low1(1),low2(2),low3(3)];

up=[up1(1),up2(2),up3(3)];

% gap(i) gives the size of the identified set of payoffs for choice y=i 
gap=abs(up-low);

