%% Function to calculate the integrated Bellman Equation
%Example input values
%dim=30;  %number of states
%b = 0.9; % discount factor 
%parameters govering per-period utilities:
%rc = 2; 
%theta11 = 0.5;
%parameters governing transition of states:
%theta30 = 0.30;  
%theta31 = 0.35;  
%theta32 = 0.25; 
%theta33 = 0.10; 

%The output of concerned is "p", the conditional choice probabilities; and
%"csvf", the choice-specific value functions

function [f,EV,p,csvf,i] = IBE(dim, b, rc, theta11, theta30, theta31, theta32, theta33)

tic

%control
iteration = 10000; 
error = 0.01; 

%transition probability when y=1 
Pi1=zeros(dim,dim);
Pi1(:,1)=theta30*ones(dim,1);
Pi1(:,2)=theta31*ones(dim,1);
Pi1(:,3)=theta32*ones(dim,1);
Pi1(:,4)=theta33*ones(dim,1);


%transition probability when y=2 
Pi2=zeros(dim,dim);

Pi2(1:10,1)=theta30*ones(10,1);
Pi2(1:10,2)=theta31*ones(10,1);
Pi2(1:10,3)=theta32*ones(10,1);
Pi2(1:10,4)=theta33*ones(10,1);

for x=11:1:dim
    
    Pi2(x,x-10)=theta30;
    Pi2(x,x-9)=theta31;
    Pi2(x,x-8)=theta32;
    Pi2(x,x-7)=theta33;
    
end

%transition probability for y=3

Pi3=zeros(dim,dim);

for x=1:1:dim-3
    
    Pi3(x,x)=theta30;
    Pi3(x,x+1)=theta31;
    Pi3(x,x+2)=theta32;
    Pi3(x,x+3)=theta33;
    
end

Pi3(dim-2,dim-2)=(theta30)/(theta30+theta31+theta32);
Pi3(dim-2,dim-1)=(theta31)/(theta30+theta31+theta32);
Pi3(dim-2,dim)=(theta32)/(theta30+theta31+theta32);
Pi3(dim-1,dim-1)=(theta30)/(theta30+theta31);
Pi3(dim-1,dim)=(theta31)/(theta30+theta31);
Pi3(dim,dim)=1;


S=5000; %number of replications to average over errors


%Value Function Iteration
V = ones(dim,1); % initialize
Vtemp = ones(dim,1); 
Vnew = ones(dim,S); % initialize

e=zeros(dim,2,S);

% Set seed for random stream
sst = RandStream('mt19937ar','Seed',4);
RandStream.setGlobalStream(sst);

for l=1:1:S
    e(:,:,l)=mvnrnd([0,0],[0.5,0.5;0.5,1],dim); %generate errors
end


for i = 1:iteration
    
    
    parfor l=1:1:S

     
    Vnew(:,l) = max([theta11*sqrt([1:1:dim]')-rc*ones(dim,1) + e(1:dim,1,l)+...
        + b*Pi1*Vtemp,...       
        ...
        0.8*theta11*sqrt([1:1:dim]')-rc*ones(dim,1) + e(1:dim,2,l)...
        + b*Pi2*Vtemp,...
        ...
        b*Pi3*Vtemp],...
        ...
        [],2);


    end
    
V=mean(Vnew,2);


if max(abs(Vtemp-V)) < error;
 Vtemp = V;   
 break;
end;

%value function update
Vtemp = V;


end


f = Vtemp;
         

EV(:,1)=Pi1*f;
EV(:,2)=Pi2*f;
EV(:,3)=Pi3*f;

%choice-specific value functions
csvf(:,1)=b*EV(:,1) - rc + theta11*sqrt([1:1:dim]');
csvf(:,2)=b*EV(:,2) - rc + 0.8*theta11*sqrt([1:1:dim]');
csvf(:,3)=b*EV(:,3);

%theoretical conditional choice probabilities

In=zeros(dim,10000);

parfor l=1:1:10000
    
    e=mvnrnd([0,0],[0.5,0.5;0.5,1],dim);
    [~,In(:,l)]=max([csvf(:,1)+e(:,1),csvf(:,2)+e(:,2),csvf(:,3)],[],2);
    
end

for r=1:1:dim
    
 p(r,1)=numel(find(In(r,:)==1))/numel(In(r,:));
 p(r,2)=numel(find(In(r,:)==2))/numel(In(r,:));
 p(r,3)=numel(find(In(r,:)==3))/numel(In(r,:));

 
end

toc

end

